package report;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.junit.Test;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * Excel Report Grouping Test
 *
 * @author strokina_a
 * @version 03.11.11
 */
public class ExcelReportGroupingTest {

    private static final String FILE_PATH_COLUMN_GROUPS = "c:\\temp\\testExcelColumnGroups.xlsx";

    @Test
    public void simple_excel_file_columns_grouping_test() throws IOException, FileNotFoundException {
        Workbook workbook = createTestWorkbook();
        Sheet sheet = createTestSheet(workbook);
        for (int i = 1; i < 11; i++) {
            sheet.setColumnWidth(i, 100);
        }
        sheet.groupColumn(1, 10);
        writeFile(workbook, FILE_PATH_COLUMN_GROUPS);
    }

    private static Workbook createTestWorkbook() {
        return new SXSSFWorkbook(100);

    }

    private static Sheet createTestSheet(Workbook workbook) {
        Sheet sheet = workbook.createSheet("Test");
        for (int rowIndex = 0; rowIndex < 100; rowIndex++) {
            Row row = sheet.createRow(rowIndex);
            for (int columnIndex = 0; columnIndex < 100; columnIndex++) {
                Cell cell = row.createCell(columnIndex);
                cell.setCellValue(String.valueOf(rowIndex) + "_" + String.valueOf(columnIndex));
            }
        }
        return sheet;
    }

    private static void writeFile(Workbook workbook, String filePath) throws IOException, FileNotFoundException {
        File excelReportFile = new File(filePath);
        FileOutputStream fos = new FileOutputStream(excelReportFile);
        workbook.write(fos);
        fos.close();
    }

}